## SYDAR: Synthesis Done Approximately Right

### Installation and usage
```
$ pip install sydar
$ sydar-matlab [input_file.miu] -o output.m
```

### References
* I. Papusha, J. Fu, U. Topcu, and R. M. Murray. "Automata Theory Meets Approximate Dynamic Programming: Optimal Control with Temporal Logic Constraints," *IEEE Conference on Decision and Control (CDC)*, pp. 434–440, Las Vegas, NV, December 12–14, 2016. 
\[[pdf](http://ivanpapusha.com/pdf/adpltl_cdc2016.pdf)\] 
\[[slides](http://ivanpapusha.com/pdf/adpltl_cdc2016_slides.pdf)\] 
\[[doi](http://dx.doi.org/10.1109/CDC.2016.7798307)\]
